@@ -2,24 +2,41 @@ package db_local
 
 import (
 	"context"
-
+	"github.com/jackc/pgx/v5"
 	"github.com/jackc/pgx/v5/pgconn"
 	"github.com/turbot/steampipe/pkg/constants"
 )
 
 func executeSqlAsRoot(ctx context.Context, statements ...string) ([]pgconn.CommandTag, error) {
-	var results []pgconn.CommandTag
-	rootClient, err := createLocalDbClient(ctx, &CreateDbOptions{Username: constants.DatabaseSuperUser})
+	rootClient, err := CreateLocalDbConnection(ctx, &CreateDbOptions{Username: constants.DatabaseSuperUser})
 	if err != nil {
 		return nil, err
 	}
-	defer rootClient.Close(ctx)
+	return executeSqlInTransaction(ctx, rootClient, statements...)
+}
+
+func executeSqlInTransaction(ctx context.Context, conn *pgx.Conn, statements ...string) (results []pgconn.CommandTag, err error) {
+
+	tx, err := conn.Begin(ctx)
+	if err != nil {
+		return nil, err
+	}
+	defer func() {
+		if err != nil {
+			tx.Rollback(ctx)
+		}
+	}()
+
 	for _, statement := range statements {
-		result, err := rootClient.Exec(ctx, statement)
+		result, err := tx.Exec(ctx, statement)
 		if err != nil {
 			return nil, err
 		}
 		results = append(results, result)
 	}
+	if err := tx.Commit(ctx); err != nil {
+		return nil, err
+	}
+
 	return results, nil
 }
