@@ -7,12 +7,19 @@ import (
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/export"
 	"github.com/turbot/steampipe/pkg/initialisation"
+	"github.com/turbot/steampipe/pkg/statushooks"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/workspace"
 )
 
 type InitData struct {
 	initialisation.InitData
+
+	// the current state that init is in
+	Status string
+	// if non-nil, this is called everytime the status changes
+	OnStatusChanged func(string)
+
 	cancelInitialisation context.CancelFunc
 	Loaded               chan struct{}
 	// map of query name to resolved query (key is the query text for command line queries)
@@ -23,36 +30,22 @@ type InitData struct {
 // It also starts an asynchronous population of the object
 // InitData.Done closes after asynchronous initialization completes
 func NewInitData(ctx context.Context, args []string) *InitData {
-	// load the workspace
-	w, errAndWarnings := workspace.LoadWorkspacePromptingForVariables(ctx)
-	if errAndWarnings.GetError() != nil {
-		return &InitData{
-			InitData: *initialisation.NewErrorInitData(fmt.Errorf("failed to load workspace: %s", errAndWarnings.GetError().Error())),
-		}
-	}
-
 	i := &InitData{
-		InitData: *initialisation.NewInitData(w),
+		InitData: *initialisation.NewInitData(),
 		Loaded:   make(chan struct{}),
 	}
-	// add any warnings
-	i.Result.AddWarnings(errAndWarnings.Warnings...)
-
-	if len(viper.GetStringSlice(constants.ArgExport)) > 0 {
-		i.RegisterExporters(queryExporters()...)
-
-		// validate required export formats
-		if err := i.ExportManager.ValidateExportFormat(viper.GetStringSlice(constants.ArgExport)); err != nil {
-			i.Result.Error = err
-			return i
-		}
-	}
-
-	go i.init(ctx, w, args)
+	go i.init(ctx, args)
 
 	return i
 }
 
+func (i *InitData) SetStatus(newStatus string) {
+	i.Status = newStatus
+	if i.OnStatusChanged != nil {
+		i.OnStatusChanged(newStatus)
+	}
+}
+
 func queryExporters() []export.Exporter {
 	return []export.Exporter{&export.SnapshotExporter{}}
 }
@@ -84,14 +77,42 @@ func (i *InitData) Cleanup(ctx context.Context) {
 	}
 }
 
-func (i *InitData) init(ctx context.Context, w *workspace.Workspace, args []string) {
+func (i *InitData) init(parentCtx context.Context, args []string) {
 	defer func() {
 		close(i.Loaded)
 		// clear the cancelInitialisation function
 		i.cancelInitialisation = nil
 	}()
+
+	// create a context with the init hook in - which can be sent down to lower level operations
+	hook := NewQueryInitStatusHook(i)
+	ctx := statushooks.AddStatusHooksToContext(parentCtx, hook)
+
+	// validate export args
+	if len(viper.GetStringSlice(constants.ArgExport)) > 0 {
+		i.RegisterExporters(queryExporters()...)
+
+		// validate required export formats
+		if err := i.ExportManager.ValidateExportFormat(viper.GetStringSlice(constants.ArgExport)); err != nil {
+			i.Result.Error = err
+			return
+		}
+	}
+
+	statushooks.SetStatus(ctx, "Loading workspace")
+	w, errAndWarnings := workspace.LoadWorkspacePromptingForVariables(ctx)
+	if errAndWarnings.GetError() != nil {
+		i.Result.Error = fmt.Errorf("failed to load workspace: %s", errAndWarnings.GetError().Error())
+		return
+	}
+	i.Result.AddWarnings(errAndWarnings.Warnings...)
+	i.Workspace = w
+
 	// set max DB connections to 1
 	viper.Set(constants.ArgMaxParallel, 1)
+
+	statushooks.SetStatus(ctx, "Resolving arguments")
+
 	// convert the query or sql file arg into an array of executable queries - check names queries in the current workspace
 	resolvedQueries, preparedStatementSource, err := w.GetQueriesFromArgs(args)
 	if err != nil {
