@@ -26,13 +26,6 @@ type ConnectionData struct {
 	SchemaHash string `json:"schema_hash,omitempty"`
 	// the creation time of the plugin file (only used for local plugins)
 	ModTime time.Time `json:"mod_time"`
-
-	// legacy properties included for backwards compatibility with v0.13
-	LegacyPlugin     string                `json:"Plugin,omitempty"`
-	LegacyConnection *modconfig.Connection `json:"Connection,omitempty"`
-	LegacySchemaMode string                `json:"SchemaMode,omitempty"`
-	LegacySchemaHash string                `json:"SchemaHash,omitempty"`
-	LegacyModTime    time.Time             `json:"ModTime,omitempty"`
 }
 
 func NewConnectionData(remoteSchema string, connection *modconfig.Connection, creationTime time.Time) *ConnectionData {
@@ -50,27 +43,6 @@ func (d *ConnectionData) IsValid() bool {
 	return d.StructVersion > 0
 }
 
-// MigrateLegacy migrates the legacy properties into new properties
-func (d *ConnectionData) MigrateLegacy() {
-	d.StructVersion = ConnectionDataStructVersion
-	d.Plugin = d.LegacyPlugin
-	d.SchemaMode = d.LegacySchemaMode
-	d.SchemaHash = d.LegacySchemaHash
-	d.ModTime = d.LegacyModTime
-	d.Connection = d.LegacyConnection
-	d.Connection.MigrateLegacy()
-}
-
-// MaintainLegacy keeps the values of the legacy properties intact while
-// refreshing connections
-func (d *ConnectionData) MaintainLegacy() {
-	d.LegacyPlugin = d.Plugin
-	d.LegacySchemaMode = d.SchemaMode
-	d.LegacySchemaHash = d.SchemaHash
-	d.LegacyModTime = d.ModTime
-	d.LegacyConnection = d.Connection
-}
-
 func (d *ConnectionData) Equals(other *ConnectionData) bool {
 	if d.Connection == nil || other.Connection == nil {
 		// if either object has a nil Connection, then it may be data from an old connection state file
@@ -79,6 +51,7 @@ func (d *ConnectionData) Equals(other *ConnectionData) bool {
 	}
 
 	return d.Plugin == other.Plugin &&
+		d.Connection.Equals(other.Connection) &&
 		d.ModTime.Equal(other.ModTime) &&
 		d.Connection.Equals(other.Connection)
 }
