@@ -7,7 +7,6 @@ import (
 	"time"
 
 	"github.com/turbot/steampipe/pkg/filepaths"
-	"github.com/turbot/steampipe/pkg/migrate"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/utils"
 )
@@ -25,18 +24,8 @@ func (m ConnectionDataMap) IsValid() bool {
 	return true
 }
 
-func (m ConnectionDataMap) MigrateFrom() migrate.Migrateable {
-	for _, v := range m {
-		v.MigrateLegacy()
-	}
-	return m
-}
-
 func (m ConnectionDataMap) Save() error {
 	connFilePath := filepaths.ConnectionStatePath()
-	for _, v := range m {
-		v.MaintainLegacy()
-	}
 	connFileJSON, err := json.MarshalIndent(m, "", "  ")
 	if err != nil {
 		log.Println("[ERROR]", "Error while writing state file", err)
@@ -86,7 +75,7 @@ func NewConnectionDataMap(connectionMap map[string]*modconfig.Connection) (Conne
 	// map of missing plugins, keyed by plugin, value is list of conections using missing plugin
 	missingPluginMap := make(map[string][]modconfig.Connection)
 
-	utils.LogTime("steampipeconfig.getRequiredConnections config-iteration start")
+	utils.LogTime("steampipeconfig.getRequiredConnections config - iteration start")
 	// populate file mod time for each referenced plugin
 	for name, connection := range connectionMap {
 		remoteSchema := connection.Plugin
@@ -112,7 +101,7 @@ func NewConnectionDataMap(connectionMap map[string]*modconfig.Connection) (Conne
 
 		requiredConnections[name] = NewConnectionData(remoteSchema, connection, modTime)
 	}
-	utils.LogTime("steampipeconfig.getRequiredConnections config-iteration end")
+	utils.LogTime("steampipeconfig.getRequiredConnections config - iteration end")
 
 	return requiredConnections, missingPluginMap, nil
 }
