@@ -1,6 +1,8 @@
 package utils
 
-import "strings"
+import (
+	"strings"
+)
 
 // UnquoteStringArray removes quote marks from elements of string array
 func UnquoteStringArray(stringArray []string) []string {
@@ -10,3 +12,8 @@ func UnquoteStringArray(stringArray []string) []string {
 	}
 	return res
 }
+
+// StringSlicesEqual returns whether the 2 string slices are identical
+func StringSlicesEqual(l, r []string) bool {
+	return strings.Join(l, ",") == strings.Join(r, ",")
+}
