@@ -11,7 +11,7 @@ func (w *Workspace) GetQueryProvider(queryName string) (modconfig.QueryProvider,
 		return nil, false
 	}
 	// try to find the resource
-	if resource, ok := modconfig.GetResource(w, parsedName); ok {
+	if resource, ok := w.GetResource(parsedName); ok {
 		// found a resource - is itr a query provider
 		if qp := resource.(modconfig.QueryProvider); ok {
 			return qp, true
@@ -33,3 +33,7 @@ func (w *Workspace) GetResourceMaps() *modconfig.ResourceMaps {
 	}
 	return w.Mod.ResourceMaps
 }
+
+func (m *Workspace) GetResource(parsedName *modconfig.ParsedResourceName) (resource modconfig.HclResource, found bool) {
+	return m.GetResourceMaps().GetResource(parsedName)
+}
