@@ -3,11 +3,13 @@ package pluginmanager_service
 import (
 	"context"
 	"crypto/md5"
+	"encoding/json"
 	"fmt"
+	"github.com/turbot/steampipe/pkg/connectionwatcher"
+	"github.com/turbot/steampipe/pkg/steampipeconfig"
 	"log"
 	"os"
 	"os/exec"
-	"runtime/debug"
 	"strconv"
 	"strings"
 	"sync"
@@ -19,6 +21,7 @@ import (
 	sdkgrpc "github.com/turbot/steampipe-plugin-sdk/v5/grpc"
 	sdkproto "github.com/turbot/steampipe-plugin-sdk/v5/grpc/proto"
 	sdkshared "github.com/turbot/steampipe-plugin-sdk/v5/grpc/shared"
+	sdkplugin "github.com/turbot/steampipe-plugin-sdk/v5/plugin"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_local"
 	"github.com/turbot/steampipe/pkg/error_helpers"
@@ -54,7 +57,7 @@ type PluginManager struct {
 	// NOTE - for legacy plugins, one entry in this map may correspond to multiple running plugins
 	pluginConnectionConfigMap map[string][]*sdkproto.ConnectionConfig
 	// map of connection configs, keyed by connection name
-	connectionConfigMap map[string]*sdkproto.ConnectionConfig
+	connectionConfigMap connectionwatcher.ConnectionConfigMap
 	// map of max cache size, keyed by plugin name
 	pluginCacheSizeMap map[string]int64
 
@@ -129,26 +132,32 @@ func (m *PluginManager) Get(req *proto.GetRequest) (*proto.GetResponse, error) {
 		}
 	}
 
-	log.Printf("[TRACE] PluginManager Get returning %+v", resp)
 	return resp, nil
 }
 
-func (m *PluginManager) SetConnectionConfigMap(configMap map[string]*sdkproto.ConnectionConfig) {
+// OnConnectionConfigChanged is the callback function invoked by the connection watcher when the config changed
+func (m *PluginManager) OnConnectionConfigChanged(configMap connectionwatcher.ConnectionConfigMap) {
 	m.mut.Lock()
 	defer m.mut.Unlock()
 
 	names := utils.SortedMapKeys(configMap)
-	log.Printf("[TRACE] SetConnectionConfigMap: %s", strings.Join(names, ","))
+	log.Printf("[TRACE] OnConnectionConfigChanged: %s", strings.Join(names, ","))
 
 	err := m.handleConnectionConfigChanges(configMap)
 	if err != nil {
 		log.Printf("[WARN] handleConnectionConfigChanges returned error: %s", err.Error())
 	}
+
 }
 
-func (m *PluginManager) Shutdown(req *proto.ShutdownRequest) (resp *proto.ShutdownResponse, err error) {
-	log.Printf("[TRACE] PluginManager Shutdown")
-	debug.PrintStack()
+// OnConnectionsChanged is the callback function invoked by the connection watcher when connections are added or removed
+func (m *PluginManager) OnConnectionsChanged(refreshResult *steampipeconfig.RefreshConnectionResult, client *db_local.LocalDbClient) {
+	notification := refreshResult.Updates.AsNotification()
+	m.notifySchemaChange(notification, client)
+}
+
+func (m *PluginManager) Shutdown(*proto.ShutdownRequest) (resp *proto.ShutdownResponse, err error) {
+	log.Printf("[INFO] PluginManager Shutdown")
 
 	m.mut.Lock()
 	defer func() {
@@ -164,15 +173,15 @@ func (m *PluginManager) Shutdown(req *proto.ShutdownRequest) (resp *proto.Shutdo
 			// shouldn't happen but has been observed in error situations
 			continue
 		}
-		log.Printf("[TRACE] killing plugin %s (%v)", name, p.reattach.Pid)
+		log.Printf("[INFO] PluginManager killing plugin %s (%v)", name, p.reattach.Pid)
 		p.client.Kill()
 	}
 	return &proto.ShutdownResponse{}, nil
 }
 
-func (m *PluginManager) handleConnectionConfigChanges(configMap map[string]*sdkproto.ConnectionConfig) error {
+func (m *PluginManager) handleConnectionConfigChanges(newConfigMap map[string]*sdkproto.ConnectionConfig) error {
 	// now determine whether there are any new or deleted connections
-	addedConnections, deletedConnections, changedConnections := m.getConnectionChanges(configMap)
+	addedConnections, deletedConnections, changedConnections := m.connectionConfigMap.Diff(newConfigMap)
 
 	requestMap := make(map[string]*sdkproto.UpdateConnectionConfigsRequest)
 
@@ -184,7 +193,7 @@ func (m *PluginManager) handleConnectionConfigChanges(configMap map[string]*sdkp
 	// for updated connections just add to request map
 	m.handleUpdatedConnections(changedConnections, requestMap)
 	// update connectionConfigMap
-	m.connectionConfigMap = configMap
+	m.connectionConfigMap = newConfigMap
 
 	// rebuild pluginConnectionConfigMap
 	m.populatePluginConnectionConfigs()
@@ -318,38 +327,21 @@ func (m *PluginManager) getPlugin(connectionConfig *sdkproto.ConnectionConfig) (
 	pluginName := connectionConfig.Plugin
 	log.Printf("[TRACE] PluginManager getPlugin %s connection '%s'\n", pluginName, connectionName)
 
-	// reason for starting the plugin (if we need to
+	// reason for starting the plugin (if we need to)
 	var reason string
 
 	// is this plugin already running
 	// lock access to plugin map
 	m.mut.Lock()
-	p, ok := m.connectionPluginMap[connectionName]
-	if ok {
-		log.Printf("[TRACE] connection %s found in connectionPluginMap\n", connectionName)
-	} else {
-		// so there is no entry in connectionPluginMap for this connection - check whether there is an entry in either
-		// - pluginMultiConnectionMap (indicating this is a multi connection plugin which has been loaded for another connection
-		// - loadingPlugins (indicating this is a plugin which is still loading and we do not yet know if it supports multi connection
-		p, ok = m.pluginMultiConnectionMap[pluginName]
-		if ok {
-			log.Printf("[TRACE] %s found in pluginMultiConnectionMap\n", pluginName)
-		}
-	}
-	if !ok {
-		p, ok = m.loadingPlugins[pluginName]
-		if ok {
-			log.Printf("[TRACE] %s found in loadingPlugins\n", pluginName)
-		}
-	}
+	runningPlugin := m.isPluginRunning(connectionName, pluginName)
 	// do we now have a plugin?
-	if ok {
+	if runningPlugin != nil {
 		// unlock access to map to allow other getPlugin calls to proceed
 		m.mut.Unlock()
 		var reattach *proto.ReattachConfig
 
 		// wait for plugin to load, verify it is running and check it provides the required connection
-		reason, reattach, err = m.verifyLoadingPlugin(connectionName, p)
+		reason, reattach, err = m.verifyLoadingPlugin(connectionName, runningPlugin)
 		if reason == "" {
 			return reattach, err
 		}
@@ -387,7 +379,7 @@ func (m *PluginManager) getPlugin(connectionConfig *sdkproto.ConnectionConfig) (
 
 	// NOTE: at this point, m.mut is locked
 	// put in a placeholder so no other thread tries to create start this plugin
-	m.addLoadingPlugin(connectionName, p, pluginName)
+	m.addLoadingPlugin(connectionName, pluginName)
 
 	// unlock access to map
 	m.mut.Unlock()
@@ -420,6 +412,29 @@ func (m *PluginManager) getPlugin(connectionConfig *sdkproto.ConnectionConfig) (
 	return reattach, nil
 }
 
+func (m *PluginManager) isPluginRunning(connectionName string, pluginName string) *runningPlugin {
+	p, ok := m.connectionPluginMap[connectionName]
+	if ok {
+		log.Printf("[TRACE] connection %s found in connectionPluginMap\n", connectionName)
+		return p
+	}
+	// so there is no entry in connectionPluginMap for this connection - check whether there is an entry in either
+	// - pluginMultiConnectionMap (indicating this is a multi connection plugin which has been loaded for another connection
+	// - loadingPlugins (indicating this is a plugin which is still loading and we do not yet know if it supports multi connection
+	p, ok = m.pluginMultiConnectionMap[pluginName]
+	if ok {
+		log.Printf("[TRACE] %s found in pluginMultiConnectionMap\n", pluginName)
+		return p
+	}
+	p, ok = m.loadingPlugins[pluginName]
+	if ok {
+		log.Printf("[TRACE] %s found in loadingPlugins\n", pluginName)
+		return p
+	}
+
+	return nil
+}
+
 // wait for plugin to load, verify it is running and check it provides the required connection
 func (m *PluginManager) verifyLoadingPlugin(connectionName string, p *runningPlugin) (string, *proto.ReattachConfig, error) {
 	var reason string
@@ -455,10 +470,10 @@ func (m *PluginManager) verifyLoadingPlugin(connectionName string, p *runningPlu
 	return reason, nil, nil
 }
 
-func (m *PluginManager) addLoadingPlugin(connectionName string, p *runningPlugin, pluginName string) {
+func (m *PluginManager) addLoadingPlugin(connectionName string, pluginName string) {
 	// add a new running plugin to both connectionPluginMap and pluginMap
 	// NOTE: m.mut must be locked before calling this
-	p = &runningPlugin{
+	p := &runningPlugin{
 		pluginName:  pluginName,
 		initialized: make(chan struct{}, 1),
 	}
@@ -618,7 +633,18 @@ func (m *PluginManager) startPlugin(connectionName string) (_ *plugin.Client, _
 
 	reattach := proto.NewReattachConfig(pluginName, client.ReattachConfig(), proto.SupportedOperationsFromSdk(supportedOperations), connectionNames)
 
-	//m.messageServer.AddConnection(pluginClient, pluginName, connectionNames...)
+	//
+	// if this plugin has a dynamic schema, add connections to message server
+	schema, err := pluginClient.GetSchema(connectionName)
+	if err != nil {
+		log.Printf("[WARN] failed to set fetch schema: %s", err.Error())
+		return nil, nil, err
+	}
+
+	if schema.Mode == sdkplugin.SchemaModeDynamic {
+		_ = m.messageServer.AddConnection(pluginClient, pluginName, connectionNames...)
+	}
+	// TODO KAI how to handle error here
 	return client, reattach, nil
 }
 
@@ -680,6 +706,8 @@ func (m *PluginManager) setSingleConnectionConfig(pluginClient *sdkgrpc.PluginCl
 	return pluginClient.SetConnectionConfig(req)
 }
 
+// update the schema for the specified connection
+// called from the message server after receiving a PluginMessageType_SCHEMA_UPDATED message from plugin
 func (m *PluginManager) updateConnectionSchema(ctx context.Context, connection string) {
 	log.Printf("[TRACE] updateConnectionSchema connection %s", connection)
 	// now refresh connections and search paths
@@ -694,31 +722,28 @@ func (m *PluginManager) updateConnectionSchema(ctx context.Context, connection s
 		log.Printf("[TRACE] error refreshing connections: %s", refreshResult.Error)
 		return
 	}
+
+	// also send a postgres notification
+	notification := steampipeconfig.NewSchemaUpdateNotification([]string{connection}, nil)
+
+	m.notifySchemaChange(notification, client)
 }
 
-func (m *PluginManager) getConnectionChanges(newConfigMap map[string]*sdkproto.ConnectionConfig) (addedConnections, deletedConnections, changedConnections map[string][]*sdkproto.ConnectionConfig) {
-	// results are maps os  connections keyed by plugin
-	addedConnections = make(map[string][]*sdkproto.ConnectionConfig)
-	deletedConnections = make(map[string][]*sdkproto.ConnectionConfig)
-	changedConnections = make(map[string][]*sdkproto.ConnectionConfig)
-
-	// TODO if anything other than the plugin specific connection config has changed,
-	// treat as a deletion and addition of a new connection
-	// https://github.com/turbot/steampipe/issues/2348
-
-	for currentName, currentConnection := range m.connectionConfigMap {
-		if newConnection, ok := newConfigMap[currentName]; !ok {
-			deletedConnections[currentConnection.Plugin] = append(deletedConnections[currentConnection.Plugin], currentConnection)
-		} else if currentConnection.Config != newConnection.Config {
-			changedConnections[currentConnection.Plugin] = append(changedConnections[currentConnection.Plugin], newConnection)
-		}
+// send a postgres notification that the schema has chganged
+func (m *PluginManager) notifySchemaChange(notification any, client *db_local.LocalDbClient) {
+	notificationBytes, err := json.Marshal(notification)
+	if err != nil {
+		log.Printf("[TRACE] error marshalling Postgres notification: %s", err.Error())
+		return
 	}
-	for newName, newConnection := range newConfigMap {
-		if _, ok := m.connectionConfigMap[newName]; !ok {
-			addedConnections[newConnection.Plugin] = append(addedConnections[newConnection.Plugin], newConnection)
-		}
+
+	log.Printf("[TRACE] Send update notification")
+
+	sql := fmt.Sprintf("select pg_notify('%s', $1)", constants.PostgresNotificationChannel)
+	_, err = client.ExecuteSync(context.Background(), sql, notificationBytes)
+	if err != nil {
+		log.Printf("[WARN] Error sending notification: %s", err)
 	}
-	return
 }
 
 func (m *PluginManager) nonAggregatorConnectionCount() int {
